@@ -6,7 +6,7 @@
 #include <string>
 #include <iostream>
 #include <RcppArmadillo.h>
-
+#define NDEBUG 1
 // [[Rcpp::depends(RcppArmadillo)]]
 
 using namespace Rcpp;
@@ -35,6 +35,21 @@ std::vector<size_t> order(std::vector<T>& values, bool decreasing) {
   }
   return indices;
 }
+/*A common purpose of using log-domain computations is to increase accuracy and avoid underflow and overflow problems when very small or very large numbers are represented directly (i.e. in a linear domain) using a limited-precision, floating point numbers.
+*/
+
+template <typename Iter>
+typename  std::iterator_traits <Iter>::value_type log_sum_exp(Iter begin, Iter end)
+{
+  using VT = typename std::iterator_traits<Iter>::value_type;
+  if (begin==end) return VT{};
+  using std::exp;
+  using std::log;
+  auto max_elem = *std::max_element(begin, end);
+  auto sum = std::accumulate(begin, end, VT{}, 
+     [max_elem](VT a, VT b) { return a + exp(b - max_elem); });
+  return max_elem + log(sum);
+}
 
 arma::mat mm_mult(NumericMatrix x,NumericMatrix y);
 arma::mat mm_transpose(NumericMatrix x,NumericMatrix y);
